@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.010-10-g8c8a060
+package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.011-10-g7b43191
 # ABSTRACT: Compare data and files at different phases of the distribution build process
 # KEYWORDS: plugin distribution configuration phase verification validation
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 use Moose;
 with
@@ -19,6 +19,8 @@ use Moose::Util 'find_meta';
 use Digest::MD5 'md5_hex';
 use List::Util 1.33 qw(none any);
 use Term::ANSIColor 3.00 'colored';
+use Storable 'dclone';
+use Test::Deep::NoTest qw(cmp_details deep_diag);
 use namespace::autoclean;
 
 # filename => [ { object => $file_object, content => $checksummed_content } ]
@@ -39,15 +41,24 @@ sub _search_all_files
 }
 
 #sub mvp_multivalue_args { qw(skip) }
-has skip => (
+has skip_file => (
     isa => 'ArrayRef[Str]',
     traits => [ 'Array' ],
-    handles => { skip => 'elements' },
+    handles => { skip_file => 'elements' },
     init_arg => undef,   # do not allow in configs just yet
     lazy => 1,
     default => sub { [ qw(Makefile.PL Build.PL) ] },
 );
 
+has skip_distmeta => (
+    isa => 'ArrayRef[Str]',
+    traits => [ 'Array' ],
+    handles => { skip_distmeta => 'elements' },
+    init_arg => undef,   # do not allow in configs just yet
+    lazy => 1,
+    default => sub { [ qw(x_static_install) ] },
+);
+
 my %zilla_constructor_args;
 
 sub BUILD
@@ -64,7 +75,7 @@ sub BUILD
     } qw(name version release_status abstract main_module authors distmeta _license_class _copyright_holder _copyright_year),
 }
 
-# nothing to put in dump_config yet...
+# no reason to include configs - this plugin does not alter the build output
 # around dump_config => sub { ... };
 
 sub before_build
@@ -174,12 +185,16 @@ sub prune_files
     }
 }
 
+my $distmeta;
+
 # since last phase,
 # new files added: no
 # files removed: no
 # files renamed: allowed
 # encoding changed: no
 # record contents: ok to now; no from now on
+# distmeta changed: ok to now; no from now on
+# no prerequisites have been added yet
 sub munge_files
 {
     my $self = shift;
@@ -228,6 +243,19 @@ sub munge_files
     my $prereq_attr = find_meta($self->zilla)->find_attribute_by_name('prereqs');
     $self->_alert('prereqs have already been read from after munging phase!')
          if Dist::Zilla->VERSION >= 5.024 and $prereq_attr->has_value($self->zilla);
+
+    # verify no prerequisites have been provided yet
+    # (it would be highly unlikely for distmeta not to be populated yet, but
+    # force it anwyay so we have something to compare to later)
+    $distmeta = dclone($self->zilla->distmeta);
+    if (exists $distmeta->{prereqs})
+    {
+        require Data::Dumper;
+        $self->_alert('prereqs have been improperly included with distribution metadata:',
+            Data::Dumper->new([ $distmeta->{prereqs} ])->Indent(2)->Terse(1)->Sortkeys(1)->Dump,
+        );
+        delete $distmeta->{prereqs};
+    }
 }
 
 # since last phase,
@@ -235,6 +263,7 @@ sub munge_files
 # files removed: no
 # files renamed: no
 # change contents: no
+# distmeta has not changed
 sub after_build
 {
     my $self = shift;
@@ -264,7 +293,7 @@ sub after_build
             # changed_by attributes
                 . '\' (' . $file->added_by . ')')
             if not $file->isa('Dist::Zilla::File::FromCode')
-                and none { $file->name eq $_ } $self->skip
+                and none { $file->name eq $_ } $self->skip_file
                 and $all_files{$file->name}[$index]{content} ne md5_hex($file->encoded_content);
 
         delete $all_files{$file->name};
@@ -276,6 +305,21 @@ sub after_build
                 . '\' (' . $_->{object}->added_by . ')')
             foreach @{ $all_files{$filename} };
     }
+
+    # check distmeta, minus prereqs
+    my $new_distmeta = dclone($self->zilla->distmeta);
+    delete $new_distmeta->{prereqs};
+    foreach my $ignore_key ($self->skip_distmeta)
+    {
+        $new_distmeta->{$ignore_key} = Test::Deep::ignore;
+        delete $new_distmeta->{$ignore_key} if not exists $distmeta->{$ignore_key};
+    }
+    my ($ok, $stack) = cmp_details($new_distmeta, $distmeta);
+    if (not $ok)
+    {
+        chomp(my $error = deep_diag($stack));
+        $self->_alert('distribution metadata has been altered after munging phase!', $error);
+    }
 }
 
 sub _alert
@@ -298,7 +342,7 @@ Dist::Zilla::Plugin::VerifyPhases - Compare data and files at different phases o
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -363,12 +407,15 @@ C<-FileGatherer> phase.
 
 Running at the end of the C<-FileMunger> phase, it verifies that no additional
 files have been added to nor removed from the distribution, nor renamed, since
-the C<-FilePruner> phase. Additionally, it verifies that the prerequisite list
-has not yet been read from, when possible.
+the C<-FilePruner> phase; and that no prerequisites have yet been provided.
+Additionally, it verifies that the prerequisite list has not yet been read
+from, when possible.
 
 Running at the end of the C<-AfterBuild> phase, the full state of all files
 are checked: files may not be added, removed, renamed nor had their content
-change.
+change. Additionally, it verifies that no distribution metadata (with the
+exception of prerequisites) has changed since the end of the C<-FileMunger>
+phase.
 
 =for stopwords FromCode
 
@@ -405,7 +452,7 @@ L<Dist::Zilla::App::Command::dumpphases>
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
 
